Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(992)

Unified Diff: chrome/browser/ui/views/frame/opaque_browser_frame_view.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Fix test Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/opaque_browser_frame_view.h
diff --git a/chrome/browser/ui/views/frame/opaque_browser_frame_view.h b/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
index f31fbdcfacc10239710d948f32b754cf467b557a..ad7b1c9a661c9698626f3f7cec44f8dd52a5c375 100644
--- a/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
@@ -59,7 +59,7 @@ class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
void SizeConstraintsChanged() override;
// views::View:
- void GetAccessibleState(ui::AXViewState* state) override;
+ void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
// views::ButtonListener:
void ButtonPressed(views::Button* sender, const ui::Event& event) override;
@@ -115,7 +115,8 @@ class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
// Returns the thickness of the border that makes up the window frame edges.
// This does not include any client edge. If |restored| is true, this is
// calculated as if the window was restored, regardless of its current state.
int FrameBorderThickness(bool restored) const;
// Returns true if the specified point is within the avatar menu buttons.
« no previous file with comments | « chrome/browser/ui/views/frame/browser_view.cc ('k') | chrome/browser/ui/views/frame/opaque_browser_frame_view.cc » ('j') | no next file with comments »
@@ -115,7 +115,8 @@ class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
// Returns the thickness of the border that makes up the window frame edges.
// This does not include any client edge. If |restored| is true, this is
- // calculated as if the window was restored, regardless of its current state.
+ // calculated as if the window was restored, regardless of its current
+ // node_data.
int FrameBorderThickness(bool restored) const;
// Returns true if the specified point is within the avatar menu buttons.

Powered by Google App Engine
This is Rietveld 408576698